@@ -16,7 +16,6 @@
 #include <qpdf/QPDF_Reserved.hh>
 #include <qpdf/QPDF_Stream.hh>
 #include <qpdf/QPDF_String.hh>
-#include <qpdf/QPDF_Unresolved.hh>
 #include <qpdf/QTC.hh>
 #include <qpdf/QUtil.hh>
 
@@ -27,29 +26,27 @@ namespace
     struct StackFrame
     {
         StackFrame(std::shared_ptr<InputSource> input) :
-            offset(input->tell()),
-            contents_string(""),
-            contents_offset(-1)
+            offset(input->tell())
         {
         }
 
         std::vector<std::shared_ptr<QPDFObject>> olist;
         qpdf_offset_t offset;
-        std::string contents_string;
-        qpdf_offset_t contents_offset;
+        std::string contents_string{""};
+        qpdf_offset_t contents_offset{-1};
+        int null_count{0};
     };
 } // namespace
 
 QPDFObjectHandle
 QPDFParser::parse(bool& empty, bool content_stream)
 {
-    // This method must take care not to resolve any objects. Don't
-    // check the type of any object without first ensuring that it is
-    // a direct object. Otherwise, doing so may have the side effect
-    // of reading the object and changing the file pointer. If you do
-    // this, it will cause a logic error to be thrown from
-    // QPDF::inParse().
+    // This method must take care not to resolve any objects. Don't check the type of any object
+    // without first ensuring that it is a direct object. Otherwise, doing so may have the side
+    // effect of reading the object and changing the file pointer. If you do this, it will cause a
+    // logic error to be thrown from QPDF::inParse().
 
+    const static std::shared_ptr<QPDFObject> null_oh = QPDF_Null::create();
     QPDF::ParseGuard pg(context);
 
     empty = false;
@@ -58,7 +55,7 @@ QPDFParser::parse(bool& empty, bool content_stream)
     bool set_offset = false;
 
     std::vector<StackFrame> stack;
-    stack.push_back(StackFrame(input));
+    stack.emplace_back(input);
     std::vector<parser_state_e> state_stack;
     state_stack.push_back(st_top);
     qpdf_offset_t offset;
@@ -67,7 +64,6 @@ QPDFParser::parse(bool& empty, bool content_stream)
     int good_count = 0;
     bool b_contents = false;
     bool is_null = false;
-    auto null_oh = QPDF_Null::create();
 
     while (!done) {
         bool bad = false;
@@ -142,11 +138,10 @@ QPDFParser::parse(bool& empty, bool content_stream)
             } else {
                 state = st_start;
                 state_stack.push_back(
-                    (tokenizer.getType() == QPDFTokenizer::tt_array_open)
-                        ? st_array
-                        : st_dictionary);
+                    (tokenizer.getType() == QPDFTokenizer::tt_array_open) ? st_array
+                                                                          : st_dictionary);
                 b_contents = false;
-                stack.push_back(StackFrame(input));
+                stack.emplace_back(input);
             }
             break;
 
@@ -156,6 +151,8 @@ QPDFParser::parse(bool& empty, bool content_stream)
 
         case QPDFTokenizer::tt_null:
             is_null = true;
+            ++frame.null_count;
+
             break;
 
         case QPDFTokenizer::tt_integer:
@@ -187,28 +184,23 @@ QPDFParser::parse(bool& empty, bool content_stream)
                 if (content_stream) {
                     object = QPDF_Operator::create(value);
                 } else if (
-                    value == "R" && state != st_top && size >= 2 &&
-                    olist.back() &&
+                    value == "R" && state != st_top && size >= 2 && olist.back() &&
                     olist.back()->getTypeCode() == ::ot_integer &&
-                    !olist.back()->getObjGen().isIndirect() &&
-                    olist.at(size - 2) &&
+                    !olist.back()->getObjGen().isIndirect() && olist.at(size - 2) &&
                     olist.at(size - 2)->getTypeCode() == ::ot_integer &&
                     !olist.at(size - 2)->getObjGen().isIndirect()) {
                     if (context == nullptr) {
                         QTC::TC("qpdf", "QPDFParser indirect without context");
-                        throw std::logic_error(
-                            "QPDFObjectHandle::parse called without context"
-                            " on an object with indirect references");
+                        throw std::logic_error("QPDFObjectHandle::parse called without context on "
+                                               "an object with indirect references");
                     }
                     auto ref_og = QPDFObjGen(
                         QPDFObjectHandle(olist.at(size - 2)).getIntValueAsInt(),
                         QPDFObjectHandle(olist.back()).getIntValueAsInt());
                     if (ref_og.isIndirect()) {
-                        // This action has the desirable side effect
-                        // of causing dangling references (references
-                        // to indirect objects that don't appear in
-                        // the PDF) in any parsed object to appear in
-                        // the object cache.
+                        // This action has the desirable side effect of causing dangling references
+                        // (references to indirect objects that don't appear in the PDF) in any
+                        // parsed object to appear in the object cache.
                         object = context->getObject(ref_og).obj;
                         indirect_ref = true;
                     } else {
@@ -218,16 +210,14 @@ QPDFParser::parse(bool& empty, bool content_stream)
                     olist.pop_back();
                     olist.pop_back();
                 } else if ((value == "endobj") && (state == st_top)) {
-                    // We just saw endobj without having read
-                    // anything.  Treat this as a null and do not move
-                    // the input source's offset.
+                    // We just saw endobj without having read anything.  Treat this as a null and do
+                    // not move the input source's offset.
                     is_null = true;
                     input->seek(input->getLastOffset(), SEEK_SET);
                     empty = true;
                 } else {
                     QTC::TC("qpdf", "QPDFParser treat word as string");
-                    warn("unknown token while reading object;"
-                         " treating as string");
+                    warn("unknown token while reading object; treating as string");
                     bad = true;
                     object = QPDF_String::create(value);
                 }
@@ -254,18 +244,15 @@ QPDFParser::parse(bool& empty, bool content_stream)
             break;
 
         default:
-            warn("treating unknown token type as null while "
-                 "reading object");
+            warn("treating unknown token type as null while reading object");
             bad = true;
             is_null = true;
             break;
         }
 
         if (object == nullptr && !is_null &&
-            (!((state == st_start) || (state == st_stop) ||
-               (state == st_eof)))) {
-            throw std::logic_error("QPDFObjectHandle::parseInternal: "
-                                   "unexpected uninitialized object");
+            (!((state == st_start) || (state == st_stop) || (state == st_eof)))) {
+            throw std::logic_error("QPDFParser:parseInternal: unexpected uninitialized object");
             is_null = true;
         }
 
@@ -279,8 +266,8 @@ QPDFParser::parse(bool& empty, bool content_stream)
             }
         }
         if (bad_count > 5) {
-            // We had too many consecutive errors without enough
-            // intervening successful objects. Give up.
+            // We had too many consecutive errors without enough intervening successful objects.
+            // Give up.
             warn("too many errors; giving up on reading object");
             state = st_top;
             is_null = true;
@@ -292,8 +279,7 @@ QPDFParser::parse(bool& empty, bool content_stream)
                 warn("parse error while reading object");
             }
             done = true;
-            // In content stream mode, leave object uninitialized to
-            // indicate EOF
+            // In content stream mode, leave object uninitialized to indicate EOF
             if (!content_stream) {
                 is_null = true;
             }
@@ -301,9 +287,10 @@ QPDFParser::parse(bool& empty, bool content_stream)
 
         case st_dictionary:
         case st_array:
-            if (!indirect_ref && !is_null) {
-                // No need to set description for direct nulls - they will
-                // become implicit.
+            if (is_null) {
+                object = null_oh;
+                // No need to set description for direct nulls - they probably will become implicit.
+            } else if (!indirect_ref) {
                 setDescription(object, input->getLastOffset());
             }
             set_offset = true;
@@ -319,24 +306,22 @@ QPDFParser::parse(bool& empty, bool content_stream)
 
         case st_stop:
             if ((state_stack.size() < 2) || (stack.size() < 2)) {
-                throw std::logic_error(
-                    "QPDFObjectHandle::parseInternal: st_stop encountered"
-                    " with insufficient elements in stack");
+                throw std::logic_error("QPDFParser::parseInternal: st_stop encountered with "
+                                       "insufficient elements in stack");
             }
             parser_state_e old_state = state_stack.back();
             state_stack.pop_back();
             if (old_state == st_array) {
-                object = QPDF_Array::create(std::move(olist));
+                object = QPDF_Array::create(std::move(olist), frame.null_count > 100);
                 setDescription(object, offset - 1);
-                // The `offset` points to the next of "[".  Set the rewind
-                // offset to point to the beginning of "[". This has been
-                // explicitly tested with whitespace surrounding the array start
-                // delimiter. getLastOffset points to the array end token and
-                // therefore can't be used here.
+                // The `offset` points to the next of "[".  Set the rewind offset to point to the
+                // beginning of "[". This has been explicitly tested with whitespace surrounding the
+                // array start delimiter. getLastOffset points to the array end token and therefore
+                // can't be used here.
                 set_offset = true;
             } else if (old_state == st_dictionary) {
-                // Convert list to map. Alternating elements are keys.  Attempt
-                // to recover more or less gracefully from invalid dictionaries.
+                // Convert list to map. Alternating elements are keys.  Attempt to recover more or
+                // less gracefully from invalid dictionaries.
                 std::set<std::string> names;
                 for (auto& obj: olist) {
                     if (obj) {
@@ -358,15 +343,11 @@ QPDFParser::parse(bool& empty, bool content_stream)
                         for (bool found_fake = false; !found_fake;) {
                             key = "/QPDFFake" + std::to_string(next_fake_key++);
                             found_fake = (names.count(key) == 0);
-                            QTC::TC(
-                                "qpdf",
-                                "QPDFParser found fake",
-                                (found_fake ? 0 : 1));
+                            QTC::TC("qpdf", "QPDFParser found fake", (found_fake ? 0 : 1));
                         }
                         warn(
                             offset,
-                            "expected dictionary key but found"
-                            " non-name object; inserting key " +
+                            "expected dictionary key but found non-name object; inserting key " +
                                 key);
                     }
                     if (dict.count(key) > 0) {
@@ -374,41 +355,36 @@ QPDFParser::parse(bool& empty, bool content_stream)
                         warn(
                             offset,
                             "dictionary has duplicated key " + key +
-                                "; last occurrence overrides earlier "
-                                "ones");
+                                "; last occurrence overrides earlier ones");
                     }
 
                     // Calculate value.
                     std::shared_ptr<QPDFObject> val;
                     if (iter != olist.end()) {
-                        val = *iter ? *iter : QPDF_Null::create();
+                        val = *iter;
                         ++iter;
                     } else {
                         QTC::TC("qpdf", "QPDFParser no val for last key");
                         warn(
                             offset,
-                            "dictionary ended prematurely; "
-                            "using null as value for last key");
+                            "dictionary ended prematurely; using null as value for last key");
                         val = QPDF_Null::create();
                     }
 
                     dict[std::move(key)] = std::move(val);
                 }
                 if (!frame.contents_string.empty() && dict.count("/Type") &&
-                    dict["/Type"].isNameAndEquals("/Sig") &&
-                    dict.count("/ByteRange") && dict.count("/Contents") &&
-                    dict["/Contents"].isString()) {
-                    dict["/Contents"] =
-                        QPDFObjectHandle::newString(frame.contents_string);
+                    dict["/Type"].isNameAndEquals("/Sig") && dict.count("/ByteRange") &&
+                    dict.count("/Contents") && dict["/Contents"].isString()) {
+                    dict["/Contents"] = QPDFObjectHandle::newString(frame.contents_string);
                     dict["/Contents"].setParsedOffset(frame.contents_offset);
                 }
                 object = QPDF_Dictionary::create(std::move(dict));
                 setDescription(object, offset - 2);
-                // The `offset` points to the next of "<<". Set the rewind
-                // offset to point to the beginning of "<<". This has been
-                // explicitly tested with whitespace surrounding the dictionary
-                // start delimiter. getLastOffset points to the dictionary end
-                // token and therefore can't be used here.
+                // The `offset` points to the next of "<<". Set the rewind offset to point to the
+                // beginning of "<<". This has been explicitly tested with whitespace surrounding
+                // the dictionary start delimiter. getLastOffset points to the dictionary end token
+                // and therefore can't be used here.
                 set_offset = true;
             }
             stack.pop_back();
@@ -430,8 +406,7 @@ QPDFParser::parse(bool& empty, bool content_stream)
 }
 
 void
-QPDFParser::setDescription(
-    std::shared_ptr<QPDFObject>& obj, qpdf_offset_t parsed_offset)
+QPDFParser::setDescription(std::shared_ptr<QPDFObject>& obj, qpdf_offset_t parsed_offset)
 {
     if (obj) {
         obj->setDescription(context, description, parsed_offset);
@@ -441,9 +416,8 @@ QPDFParser::setDescription(
 void
 QPDFParser::warn(QPDFExc const& e) const
 {
-    // If parsing on behalf of a QPDF object and want to give a
-    // warning, we can warn through the object. If parsing for some
-    // other reason, such as an explicit creation of an object from a
+    // If parsing on behalf of a QPDF object and want to give a warning, we can warn through the
+    // object. If parsing for some other reason, such as an explicit creation of an object from a
     // string, then just throw the exception.
     if (context) {
         context->warn(e);
@@ -455,8 +429,7 @@ QPDFParser::warn(QPDFExc const& e) const
 void
 QPDFParser::warn(qpdf_offset_t offset, std::string const& msg) const
 {
-    warn(QPDFExc(
-        qpdf_e_damaged_pdf, input->getName(), object_description, offset, msg));
+    warn(QPDFExc(qpdf_e_damaged_pdf, input->getName(), object_description, offset, msg));
 }
 
 void
