@@ -13,7 +13,7 @@ QPDF_Operator::create(std::string const& val)
 }
 
 std::shared_ptr<QPDFObject>
-QPDF_Operator::shallowCopy()
+QPDF_Operator::copy(bool shallow)
 {
     return create(val);
 }
@@ -29,9 +29,3 @@ QPDF_Operator::getJSON(int json_version)
 {
     return JSON::makeNull();
 }
-
-std::string
-QPDF_Operator::getVal() const
-{
-    return this->val;
-}
