@@ -22,15 +22,13 @@ QPDF_Reserved::copy(bool shallow)
 std::string
 QPDF_Reserved::unparse()
 {
-    throw std::logic_error(
-        "QPDFObjectHandle: attempting to unparse a reserved object");
+    throw std::logic_error("QPDFObjectHandle: attempting to unparse a reserved object");
     return "";
 }
 
 JSON
 QPDF_Reserved::getJSON(int json_version)
 {
-    throw std::logic_error(
-        "QPDFObjectHandle: attempting to get JSON from a reserved object");
+    throw std::logic_error("QPDFObjectHandle: attempting to get JSON from a reserved object");
     return JSON::makeNull();
 }
